==> tecfy_core_package-0.1.3.tar.gz: lib/views/components/entity/dropdown_advance.property.dart <==
part of tecfy_core_client_package;

class DropdownAdvancedEntity extends StatefulWidget {
  final Entity entity;
  final String url;
  final String label;
  final Map<String,dynamic> data;
  final PropertyDropdown property;
  final void Function(String,Map) onChanged;  
  DropdownAdvancedEntity({this.property,this.label,this.entity,this.url,this.onChanged,this.data});
  @override
  _DropdownAdvancedEntityState createState() => _DropdownAdvancedEntityState();
}

class _DropdownAdvancedEntityState extends State<DropdownAdvancedEntity> {

  List<dynamic> listData;

  String get _value => dataValue['id'];
  String _initValue;
  Map<String,dynamic> dataValue;
  Entity _entity;
  String entityPropName;

  dynamic defaultParentData ={ 'id':null};

  @override
  void initState() {
   
    super.initState();
    init();
  }

  init(){
    _initValue = widget.data[widget.property.dbName];
    
    if(_entity == null) _entity = widget.entity;
    if(entityPropName == null) entityPropName = widget.property.dbName.substring(0, widget.property.dbName.indexOf("Id"));

    if(dataValue == null || dataValue['id'] != _initValue)  
      dataValue = widget.data[entityPropName];
    
  }

  openSearchDialog()async{
    await AppNavigator.showAppDialog(context,
     (listDialogContext)=>
      Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Expanded(child: Container()),
          Container(width: min(500,MediaQuery.of(context).size.width),height: min(800,MediaQuery.of(context).size.height), child: Card(child:Column( mainAxisAlignment: MainAxisAlignment.start, crossAxisAlignment: CrossAxisAlignment.stretch ,children: <Widget>[
        Container(color: ThemeService.background2Color,child: Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: <Widget>[ Padding(padding: EdgeInsets.only(left:10), child: Text(widget.label, style:ThemeService.titleStyle)), IconButton(icon: Icon(Icons.close),onPressed: ()=>Navigator.pop(listDialogContext))])),
        Expanded(child:EntityListSearchComponent(
          property:widget.property,
          entity: widget.entity,
          url: widget.url,
          data:widget.data,
          // isFilter: widget.isFilter ,
          // filterValue: widget.filterValue,
          // filterField: widget.filterField,
          urlFilterData: widget.data,
          onClick: (v){
                dataValue = v;
                print(dataValue);
                widget.data[entityPropName] = dataValue;
                if(widget.onChanged != null)widget.onChanged(_value,dataValue);
                setState(() {});
                Navigator.pop(listDialogContext);
            },)),
          FlatButton(child:Text('Add New Item', style: ThemeService.flatButtonTextStyle),onPressed: ()async{
             Map<String,dynamic> newDataRaw = new Map<String,dynamic>();
             var addNewResult = await AppNavigator.showAppDialog(listDialogContext,(addDialogContext)=> 
               Card(child: ListView(
                  children: <Widget>[
                    InLineForm(inPopup:true,data: newDataRaw,entity: _entity,onChanged: (v){}),
                    Padding(padding: EdgeInsets.symmetric(horizontal: 20),child:Row(children: <Widget>[
                      Expanded(child: AppButtonPost(label:'Save',onPressed:()async{
                        var validateResult = EntityService.validateEntity(_entity, newDataRaw);
                        if(!validateResult.success){
                          AppNavigator.showMessage(addDialogContext, validateResult.message);
                          return;
                        }
                        var addResult = await EntityService.addEntity(_entity,newDataRaw);
                        if(addResult.success){
                          dataValue = addResult.data;
                          widget.data[entityPropName] = dataValue;
                          _initValue = addResult.data['id'];
                          widget?.onChanged(_initValue,null);
                          Navigator.pop(addDialogContext,true); // close the add new item's form
                        }else{
                          AppNavigator.showMessage(addDialogContext, addResult.message);
                        }
                      })),
                      Expanded(child: FlatButton(child:Text('Cancel', style: ThemeService.flatButtonTextStyle),onPressed:()=>Navigator.pop(addDialogContext,false)))
                    ],)),
                  ],
                ))
              );
              if(addNewResult ?? false)
                Navigator.pop(listDialogContext); // close the search form
          },)
        ]))),
        Expanded(child: Container()),
        ],)
       
    );
    //loadData();
  }

  @override
  Widget build(BuildContext context) {
    
    if(_initValue != widget.data[widget.property.dbName] || dataValue == null || dataValue['id'] != _initValue) init();
    
    return MaterialButton(
      padding: EdgeInsets.all(0),
      onPressed: openSearchDialog,
      child:Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        SizedBox(height: 10),
        Text(widget.label ?? '',style: TextStyle(color: ThemeService.black26Gray, fontSize: 11)),
        Text(dataValue == null ? 'Click to Select' : (dataValue[_entity.displayField.dbName] ?? 'N/A'),style: TextStyle(color: Colors.black, fontSize: 15)),
        SizedBox(height: 10),
        Container(height: 1,color: ThemeService.black26Gray),
        SizedBox(height: 5),
      ],
    ));
  }

}

==> tecfy_core_package-0.1.8.tar.gz: lib/views/components/entity/dropdown_advance.property.dart <==
part of tecfy_core_client_package;

class DropdownAdvancedEntity extends StatefulWidget {
  final Entity entity;
  final String url;
  final String label;
  final Map<String,dynamic> data;
  final PropertyDropdown property;
  final void Function(String,Map) onChanged;  
  DropdownAdvancedEntity({this.property,this.label,this.entity,this.url,this.onChanged,this.data});
  @override
  _DropdownAdvancedEntityState createState() => _DropdownAdvancedEntityState();
}

class _DropdownAdvancedEntityState extends State<DropdownAdvancedEntity> {

  List<dynamic> listData;

  String get _value => dataValue['id'];
  String _initValue;
  Map<String,dynamic> dataValue;
  Entity _entity;
  String entityPropName;

  dynamic defaultParentData ={ 'id':null};

  @override
  void initState() {
   
    super.initState();
    init();
  }

  init(){
    _initValue = widget.data[widget.property.dbName];
    
    if(_entity == null) _entity = widget.entity;
    if(entityPropName == null) entityPropName = widget.property.dbName.substring(0, widget.property.dbName.indexOf("Id"));

    if(dataValue == null || dataValue['id'] != _initValue)  
      dataValue = widget.data[entityPropName];
    
  }

  openSearchDialog()async{
    await AppNavigator.showAppDialog(context,
     (listDialogContext)=>
      Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Expanded(child: Container()),
          Container(width: min(500,MediaQuery.of(context).size.width),height: min(800,MediaQuery.of(context).size.height), child: Card(child:Column( mainAxisAlignment: MainAxisAlignment.start, crossAxisAlignment: CrossAxisAlignment.stretch ,children: <Widget>[
        Container(color: ThemeService.backgroundSecondColor,child: Row(mainAxisAlignment: MainAxisAlignment.spaceBetween, children: <Widget>[ Padding(padding: EdgeInsets.only(left:10), child: Text(widget.label, style:ThemeService.titleStyle)), IconButton(icon: Icon(Icons.close),onPressed: ()=>Navigator.pop(listDialogContext))])),
        Expanded(child:EntityListSearchComponent(
          property:widget.property,
          entity: widget.entity,
          url: widget.url,
          data:widget.data,
          // isFilter: widget.isFilter ,
          // filterValue: widget.filterValue,
          // filterField: widget.filterField,
          urlFilterData: widget.data,
          onClick: (v){
                dataValue = v;
                print(dataValue);
                widget.data[entityPropName] = dataValue;
                if(widget.onChanged != null)widget.onChanged(_value,dataValue);
                setState(() {});
                Navigator.pop(listDialogContext);
            },)),
          FlatButton(child:Text('Add New Item', style: ThemeService.flatButtonTextStyle),onPressed: ()async{
             Map<String,dynamic> newDataRaw = new Map<String,dynamic>();
             var addNewResult = await AppNavigator.showAppDialog(listDialogContext,(addDialogContext)=> 
               Card(child: ListView(
                  children: <Widget>[
                    InLineForm(inPopup:true,data: newDataRaw,entity: _entity,onChanged: (v){}),
                    Padding(padding: EdgeInsets.symmetric(horizontal: 20),child:Row(children: <Widget>[
                      Expanded(child: AppButtonPost(label:'Save',onPressed:()async{
                        var validateResult = EntityService.validateEntity(_entity, newDataRaw);
                        if(!validateResult.success){
                          AppNavigator.showMessage(addDialogContext, validateResult.message);
                          return;
                        }
                        var addResult = await EntityService.addEntity(_entity,newDataRaw);
                        if(addResult.success){
                          dataValue = addResult.data;
                          widget.data[entityPropName] = dataValue;
                          _initValue = addResult.data['id'];
                          widget?.onChanged(_initValue,null);
                          Navigator.pop(addDialogContext,true); // close the add new item's form
                        }else{
                          AppNavigator.showMessage(addDialogContext, addResult.message);
                        }
                      })),
                      Expanded(child: FlatButton(child:Text('Cancel', style: ThemeService.flatButtonTextStyle),onPressed:()=>Navigator.pop(addDialogContext,false)))
                    ],)),
                  ],
                ))
              );
              if(addNewResult ?? false)
                Navigator.pop(listDialogContext); // close the search form
          },)
        ]))),
        Expanded(child: Container()),
        ],)
       
    );
    //loadData();
  }

  @override
  Widget build(BuildContext context) {
    
    if(_initValue != widget.data[widget.property.dbName] || dataValue == null || dataValue['id'] != _initValue) init();
    
    return MaterialButton(
      padding: EdgeInsets.all(0),
      onPressed: openSearchDialog,
      child:Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        SizedBox(height: 10),
        Text(widget.label ?? '',style: TextStyle(color: ThemeService.mainColor, fontSize: 11)),
        Text(dataValue == null ? 'Click to Select' : (dataValue[_entity.displayField.dbName] ?? 'N/A'),style: TextStyle(color: Colors.black, fontSize: 15)),
        SizedBox(height: 10),
        Container(height: 1,color: ThemeService.backgroundSecondColor),
        SizedBox(height: 5),
      ],
    ));
  }

}
